pub struct CompileOpts {Show 23 fields
pub input: Vec<String>,
pub import_remappings: Vec<ImportRemapping>,
pub base_path: Option<PathBuf>,
pub include_paths: Vec<PathBuf>,
pub allow_paths: Vec<PathBuf>,
pub language: Language,
pub threads: Threads,
pub evm_version: EvmVersion,
pub stop_after: Option<CompilerStage>,
pub optimization: OptimizationMode,
pub out_dir: Option<PathBuf>,
pub emit: Vec<CompilerOutput>,
pub standard_json: bool,
pub color: ColorChoice,
pub verbose: bool,
pub pretty_json: bool,
pub pretty_json_err: bool,
pub error_format: ErrorFormat,
pub error_format_human: HumanEmitterKind,
pub diagnostic_width: Option<usize>,
pub no_warnings: bool,
pub allow: Vec<String>,
pub unstable: UnstableOpts,
/* private fields */
}cli only.Expand description
Compilation configuration.
Fields
input: Vec<String>Files to compile, or import remappings.
- specifies standard input.
In Standard JSON mode, no input or - reads from standard input; otherwise, exactly one
input file may be specified.
Import remappings are specified as [context:]prefix=path.
See https://docs.soliditylang.org/en/latest/path-resolution.html#import-remapping.
import_remappings: Vec<ImportRemapping>Import remappings.
This is either added manually when constructing the session or parsed from input into
this field.
See https://docs.soliditylang.org/en/latest/path-resolution.html#import-remapping.
base_path: Option<PathBuf>Use the given path as the root of the source tree.
include_paths: Vec<PathBuf>Directory to search for files.
Can be used multiple times.
allow_paths: Vec<PathBuf>Allow a given path for imports.
language: LanguageSource code language. Only Solidity is currently implemented.
threads: ThreadsNumber of threads to use. Zero specifies the number of logical cores.
evm_version: EvmVersionEVM version.
stop_after: Option<CompilerStage>Stop execution after the given compiler stage.
optimization: OptimizationModeMIR optimization objective.
out_dir: Option<PathBuf>Directory to write output files.
emit: Vec<CompilerOutput>Comma separated list of types of output for the compiler to emit.
standard_json: boolSwitch to Standard JSON input/output mode.
color: ColorChoiceColoring.
verbose: boolUse verbose output.
pretty_json: boolPretty-print JSON output.
Does not include errors. See --pretty-json-err.
pretty_json_err: boolPretty-print error JSON output.
error_format: ErrorFormatHow errors and other messages are produced.
error_format_human: HumanEmitterKindHuman-readable error message style.
diagnostic_width: Option<usize>Terminal width for error message formatting.
no_warnings: boolWhether to disable warnings.
allow: Vec<String>Comma separated list of diagnostic codes to allow.
unstable: UnstableOptsParsed unstable flags.
Implementations
Sourceimpl CompileOpts
impl CompileOpts
Sourcepub const fn optimize_mir(&self) -> bool
pub const fn optimize_mir(&self) -> bool
Returns whether MIR optimization passes should run during codegen.