DeferredConst

Struct DeferredConst 

pub struct DeferredConst(/* private fields */);
A deferred constant identifier.

Deferred constants are immediates whose final value is only known after bytecode emission has observed lazy backend state, such as exact spill slot allocation. They must be resolved before assembly.

Implementations

Source

impl DeferredConst

pub const MAX_INDEX: usize

The maximum representable index value.

pub const CHECKS_MAX_INDEX: bool = true

Whether this index type performs bounds checking.

pub const fn new(value: usize) -> DeferredConst

Create a new index from a usize value.

Panics

Panics if value > MAX_INDEX.

pub const fn from_raw(value: NonMaxU32) -> DeferredConst

Create an index from a raw NonMaxU32 value.

pub fn from_foreign<F>(value: F) -> DeferredConst
where F: Idx,

Convert an index from another index type.

pub const unsafe fn from_usize_unchecked(value: usize) -> DeferredConst

Create an index from a usize without bounds checking.

SAFETY

The caller must ensure value < (u32::MAX as usize).

pub const unsafe fn from_raw_unchecked(raw: u32) -> DeferredConst

Create an index from a raw u32 without bounds checking.

SAFETY

The caller must ensure the value is not u32::MAX.

pub const fn from_usize(value: usize) -> DeferredConst

Create an index from a usize with bounds checking.

Panics

Panics if value > MAX_INDEX.

pub const fn index(self) -> usize

Get the index value as a usize.

pub const fn raw(self) -> NonMaxU32

Get the raw NonMaxU32 value.

Source

impl DeferredConst

pub const MAX: DeferredConst

The maximum index value.