pub enum FreelyGenerable {
Immediate,
Argument,
FunctionLabel,
}Expand description
Represents a “freely generable” value that can be pushed without being on the stack. These values don’t need to be in the source layout when shuffling.
Variants
Immediate
An immediate value (literal).
Argument
A function argument (can be loaded from calldata).
FunctionLabel
A function label (for internal calls).