pub struct BlockStackLayout {
pub slots: SmallVec<[Option<ValueId>; 8]>,
}Expand description
Represents a stack layout for a block - the values that should be on the stack when entering or exiting a block, from top to bottom.
Fields
slots: SmallVec<[Option<ValueId>; 8]>Stack slots from top (index 0) to bottom.
None means “don’t care” / junk slot.
Implementations
Sourceimpl BlockStackLayout
impl BlockStackLayout
Sourcepub fn new() -> BlockStackLayout
pub fn new() -> BlockStackLayout
Creates an empty layout.
Sourcepub fn from_values(
values: impl IntoIterator<Item = ValueId>,
) -> BlockStackLayout
pub fn from_values( values: impl IntoIterator<Item = ValueId>, ) -> BlockStackLayout
Creates a layout with the given values (first = top of stack).
Sourcepub fn from_stack_model(model: &StackModel) -> BlockStackLayout
pub fn from_stack_model(model: &StackModel) -> BlockStackLayout
Creates a layout from a StackModel.
Sourcepub fn to_target_layout(&self) -> Vec<TargetSlot>
pub fn to_target_layout(&self) -> Vec<TargetSlot>
Converts to a target layout for the shuffler.