pub fn contract_bytecode_dependencies(
gcx: Gcx<'_>,
contract_id: ContractId,
) -> HashSet<ContractId, FxBuildHasher>Expand description
Returns contracts whose creation bytecode is referenced by contract_id.
pub fn contract_bytecode_dependencies(
gcx: Gcx<'_>,
contract_id: ContractId,
) -> HashSet<ContractId, FxBuildHasher>Returns contracts whose creation bytecode is referenced by contract_id.