pub struct InstId(/* private fields */);Expand description
A unique identifier for an instruction in the MIR.
Implementations
Sourceimpl InstId
impl InstId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub fn from_foreign<F>(value: F) -> InstIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> InstIdwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> InstId
pub const unsafe fn from_usize_unchecked(value: usize) -> InstId
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> InstId
pub const unsafe fn from_raw_unchecked(raw: u32) -> InstId
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> InstId
pub const fn from_usize(value: usize) -> InstId