FunctionPass

Trait FunctionPass 

pub trait FunctionPass {
    // Required methods
    fn name(&self) -> &str;
    fn run_on_function(&mut self, func: &mut Function) -> bool;
}
A transformation pass that mutates one function at a time.

Required Methods

fn name(&self) -> &str

The name of this pass, for debugging and logging.

fn run_on_function(&mut self, func: &mut Function) -> bool

Runs the transformation on the given function.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors