pub struct ConstantEvaluator<'gcx> {
pub gcx: Gcx<'gcx>,
/* private fields */
}Expand description
Evaluates Solidity constant expressions.
This supports the source-level constants needed by semantic analysis and codegen’s HIR lowering pre-folds. It does not evaluate runtime-dependent expressions such as function calls or memory allocation.
Fields
gcx: Gcx<'gcx>Implementations
Sourceimpl<'gcx> ConstantEvaluator<'gcx>
impl<'gcx> ConstantEvaluator<'gcx>
Sourcepub fn new(gcx: Gcx<'gcx>) -> ConstantEvaluator<'gcx>
pub fn new(gcx: Gcx<'gcx>) -> ConstantEvaluator<'gcx>
Creates a new constant evaluator.
Sourcepub fn eval(&mut self, expr: &Expr<'_>) -> Result<IntScalar, ErrorGuaranteed>
pub fn eval(&mut self, expr: &Expr<'_>) -> Result<IntScalar, ErrorGuaranteed>
Evaluates the given expression, emitting an error diagnostic if it fails.
Sourcepub fn try_eval(&mut self, expr: &Expr<'_>) -> Result<IntScalar, EvalError>
pub fn try_eval(&mut self, expr: &Expr<'_>) -> Result<IntScalar, EvalError>
Evaluates the given expression, returning an error if it fails.
Sourcepub fn eval_value(
&mut self,
expr: &Expr<'_>,
) -> Result<ConstValue, ErrorGuaranteed>
pub fn eval_value( &mut self, expr: &Expr<'_>, ) -> Result<ConstValue, ErrorGuaranteed>
Evaluates the given expression to a typed constant value, emitting an error diagnostic if it fails.
Sourcepub fn try_eval_value(
&mut self,
expr: &Expr<'_>,
) -> Result<ConstValue, EvalError>
pub fn try_eval_value( &mut self, expr: &Expr<'_>, ) -> Result<ConstValue, EvalError>
Evaluates the given expression to a typed constant value, returning an error if it fails.
Sourcepub fn emit_eval_error(
&self,
expr: &Expr<'_>,
err: EvalError,
) -> ErrorGuaranteed
pub fn emit_eval_error( &self, expr: &Expr<'_>, err: EvalError, ) -> ErrorGuaranteed
Emits a diagnostic for the given evaluation error.