IntScalar

Struct IntScalar 

pub struct IntScalar { /* private fields */ }
Represents an integer value for constant evaluation.

Implementations

Source

impl IntScalar

pub fn new(data: Uint<256, 4>) -> IntScalar

Creates a new non-negative integer value.

pub fn from_bool(value: bool) -> IntScalar

Creates a new integer value from a boolean.

pub fn from_be_bytes(bytes: &[u8]) -> IntScalar

Creates a new integer value from big-endian bytes.

Panics

Panics if bytes is empty or has a length greater than 32.

pub fn bit_len(&self) -> u64

Returns the bit length of the integer value.

This is the number of bits needed for the literal type.

pub fn is_negative(&self) -> bool

Returns whether the value is negative.

pub fn is_signed(&self) -> bool

Returns whether the value requires a signed integer type.

pub fn is_zero(&self) -> bool

Returns whether the integer value is zero.

pub fn as_u256(&self) -> Option<Uint<256, 4>>

Returns the non-negative integer value as unsigned data.

pub fn as_evm_word(&self) -> Uint<256, 4>

Returns the 256-bit two’s-complement EVM word for this integer value.

pub fn to_bool(&self) -> bool

Converts the integer value to a boolean.

pub fn unop(self, op: UnOpKind) -> Result<IntScalar, EvalErrorKind>

Applies the given unary operation to this value.

pub fn binop( self, r: IntScalar, op: BinOpKind, ) -> Result<IntScalar, EvalErrorKind>

Applies the given binary operation to this value.

For literal arithmetic, this preserves the exact mathematical value.