pub struct ErrorId(/* private fields */);Expand description
An Error ID.
Implementations
Sourceimpl ErrorId
impl ErrorId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub fn from_foreign<F>(value: F) -> ErrorIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> ErrorIdwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> ErrorId
pub const unsafe fn from_usize_unchecked(value: usize) -> ErrorId
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> ErrorId
pub const unsafe fn from_raw_unchecked(raw: u32) -> ErrorId
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> ErrorId
pub const fn from_usize(value: usize) -> ErrorId