pub struct SourceId(/* private fields */);Expand description
A Source ID.
Implementations
Sourceimpl SourceId
impl SourceId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub const fn from_raw(value: NonMaxU32) -> SourceId
pub const fn from_raw(value: NonMaxU32) -> SourceId
Create an index from a raw NonMaxU32 value.
Sourcepub fn from_foreign<F>(value: F) -> SourceIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> SourceIdwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> SourceId
pub const unsafe fn from_usize_unchecked(value: usize) -> SourceId
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> SourceId
pub const unsafe fn from_raw_unchecked(raw: u32) -> SourceId
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> SourceId
pub const fn from_usize(value: usize) -> SourceId