pub struct VariableId(/* private fields */);Expand description
A Variable ID.
Implementations
Sourceimpl VariableId
impl VariableId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub const fn new(value: usize) -> VariableId
pub const fn new(value: usize) -> VariableId
Sourcepub const fn from_raw(value: NonMaxU32) -> VariableId
pub const fn from_raw(value: NonMaxU32) -> VariableId
Create an index from a raw NonMaxU32 value.
Sourcepub fn from_foreign<F>(value: F) -> VariableIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> VariableIdwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> VariableId
pub const unsafe fn from_usize_unchecked(value: usize) -> VariableId
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> VariableId
pub const unsafe fn from_raw_unchecked(raw: u32) -> VariableId
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> VariableId
pub const fn from_usize(value: usize) -> VariableId
Sourceimpl VariableId
impl VariableId
Sourcepub const MAX: VariableId
pub const MAX: VariableId
The maximum index value.