pub enum TyConvertError {
Incompatible,
NonDerivedContract,
InvalidConversion,
AttachedFunction,
LiteralTooLarge,
ContractNotPayable,
AddressNotPayable,
}Variants
Incompatible
Generic incompatibility (fallback).
NonDerivedContract
Contract doesn’t inherit from target contract.
InvalidConversion
Invalid conversion between types.
AttachedFunction
Attached function cannot be converted to an unattached function pointer.
LiteralTooLarge
Literal is larger than the target type.
ContractNotPayable
Contract cannot be converted to address payable because it cannot receive ether.
AddressNotPayable
Non-payable address cannot be converted to a contract that can receive ether.
Implementations