pub struct MemberCompletion<'gcx> {
pub member: Member<'gcx>,
pub resolved: Option<ResolvedMember>,
}Expand description
A completion candidate for a member visible on a receiver type.
Fields
member: Member<'gcx>The visible member candidate.
resolved: Option<ResolvedMember>The source-level target for the member, if one can be identified.