pub struct TyFlags(/* private fields */);Expand description
Ty flags.
Implementations
Sourceimpl TyFlags
impl TyFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<TyFlags>
pub const fn from_bits(bits: u8) -> Option<TyFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> TyFlags
pub const fn from_bits_truncate(bits: u8) -> TyFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> TyFlags
pub const fn from_bits_retain(bits: u8) -> TyFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<TyFlags>
pub fn from_name(name: &str) -> Option<TyFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: TyFlags) -> bool
pub const fn intersects(&self, other: TyFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: TyFlags) -> bool
pub const fn contains(&self, other: TyFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: TyFlags)
pub fn remove(&mut self, other: TyFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: TyFlags)
pub fn toggle(&mut self, other: TyFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: TyFlags, value: bool)
pub fn set(&mut self, other: TyFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: TyFlags) -> TyFlags
pub const fn intersection(self, other: TyFlags) -> TyFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: TyFlags) -> TyFlags
pub const fn union(self, other: TyFlags) -> TyFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: TyFlags) -> TyFlags
pub const fn difference(self, other: TyFlags) -> TyFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: TyFlags) -> TyFlags
pub const fn symmetric_difference(self, other: TyFlags) -> TyFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> TyFlags
pub const fn complement(self) -> TyFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl TyFlags
impl TyFlags
Sourcepub const fn iter(&self) -> Iter<TyFlags>
pub const fn iter(&self) -> Iter<TyFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TyFlags>
pub const fn iter_names(&self) -> IterNames<TyFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.