pub struct EvmIrBlockId(/* private fields */);Expand description
A unique identifier for a basic block in EVM IR.
Implementations
Sourceimpl EvmIrBlockId
impl EvmIrBlockId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub const fn new(value: usize) -> EvmIrBlockId
pub const fn new(value: usize) -> EvmIrBlockId
Sourcepub const fn from_raw(value: NonMaxU32) -> EvmIrBlockId
pub const fn from_raw(value: NonMaxU32) -> EvmIrBlockId
Create an index from a raw NonMaxU32 value.
Sourcepub fn from_foreign<F>(value: F) -> EvmIrBlockIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> EvmIrBlockIdwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> EvmIrBlockId
pub const unsafe fn from_usize_unchecked(value: usize) -> EvmIrBlockId
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> EvmIrBlockId
pub const unsafe fn from_raw_unchecked(raw: u32) -> EvmIrBlockId
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> EvmIrBlockId
pub const fn from_usize(value: usize) -> EvmIrBlockId
Sourceimpl EvmIrBlockId
impl EvmIrBlockId
Sourcepub const MAX: EvmIrBlockId
pub const MAX: EvmIrBlockId
The maximum index value.