pub struct InlineConfig {
pub max_statements: usize,
pub max_statements_aggressive: usize,
pub inline_single_call: bool,
pub loop_inline_multiplier: f32,
pub max_inline_depth: usize,
}Expand description
Configuration for function inlining.
Fields
max_statements: usizeMaximum number of statements in a function to consider for inlining. Functions with more statements than this are not inlined.
max_statements_aggressive: usizeMaximum number of statements for aggressive inlining.
inline_single_call: boolAlways inline functions called only once.
loop_inline_multiplier: f32Inline threshold multiplier for functions called in loops.
max_inline_depth: usizeMaximum inline depth (to prevent excessive code bloat).
Implementations
Sourceimpl InlineConfig
impl InlineConfig
Sourcepub fn for_opt_level(level: OptLevel) -> InlineConfig
pub fn for_opt_level(level: OptLevel) -> InlineConfig
Creates an inline configuration for the given optimization level.
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Returns true if inlining is disabled.