pub struct Label(/* private fields */);Expand description
A label identifier.
Implementations
Sourceimpl Label
impl Label
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub fn from_foreign<F>(value: F) -> Labelwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> Labelwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> Label
pub const unsafe fn from_usize_unchecked(value: usize) -> Label
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> Label
pub const unsafe fn from_raw_unchecked(raw: u32) -> Label
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> Label
pub const fn from_usize(value: usize) -> Label