Module

Struct Module 

pub struct Module {
    pub name: Ident,
    pub functions: IndexVec<FunctionId, Function>,
    pub data_segments: Vec<DataSegment>,
    pub storage_layout: Vec<StorageSlot>,
    pub immutables: Vec<ImmutableSlot>,
    pub is_interface: bool,
}
A MIR module representing a compiled contract.

Fields

name: Ident

Module/contract name.

functions: IndexVec<FunctionId, Function>

All functions in this module.

data_segments: Vec<DataSegment>

Data segments (for string literals, etc.).

storage_layout: Vec<StorageSlot>

Storage layout.

immutables: Vec<ImmutableSlot>

Immutable scratch-area layout (currently one staged word per immutable).

is_interface: bool

Whether this is an interface (no bytecode generation).

Implementations

Source

impl Module

pub fn new(name: Ident) -> Module

Creates a new module.

pub fn add_function(&mut self, function: Function) -> FunctionId

Adds a function to the module.

pub fn function(&self, id: FunctionId) -> &Function

Returns the function for the given ID.

pub fn function_mut(&mut self, id: FunctionId) -> &mut Function

Returns a mutable reference to the function.

pub fn add_data_segment(&mut self, data: Vec<u8>) -> usize

Adds a data segment.

pub fn add_storage_slot(&mut self, slot: StorageSlot) -> usize

Adds a storage slot.

pub fn add_immutable_slot(&mut self, slot: ImmutableSlot) -> usize

Adds an immutable data slot.

pub fn immutable_data_len(&self) -> usize

Returns the size in bytes of the constructor scratch area that stages immutable words before they are patched into the runtime code.

pub fn iter_functions(&self) -> impl Iterator<Item = (FunctionId, &Function)>

Returns an iterator over all functions.

pub fn to_text(&self) -> impl Display

Returns the human-readable textual MIR representation of this module.

pub fn to_dot(&self) -> impl Display

Returns this module’s DOT-format CFGs.