pub struct DenseBitSet<T> { /* private fields */ }Expand description
A fixed-size bitset type with a dense representation.
Note 1: Since this bitset is dense, if your domain is big, and/or relatively
homogeneous (for example, with long runs of bits set or unset), then it may
be preferable to instead use a MixedBitSet, or an
IntervalSet. They should be more suited to
sparse, or highly-compressible, domains.
Note 2: Use GrowableBitSet if you need support for resizing after creation.
T is an index type, typically a newtyped usize wrapper, but it can also
just be usize.
All operations that involve an element will panic if the element is equal to or greater than the domain size. All operations that involve two bitsets will panic if the bitsets have differing domain sizes.
Implementations
Sourceimpl<T> DenseBitSet<T>
impl<T> DenseBitSet<T>
Sourcepub fn domain_size(&self) -> usize
pub fn domain_size(&self) -> usize
Gets the domain size.
Sourceimpl<T> DenseBitSet<T>where
T: Idx,
impl<T> DenseBitSet<T>where
T: Idx,
Sourcepub fn new_empty(domain_size: usize) -> DenseBitSet<T>
pub fn new_empty(domain_size: usize) -> DenseBitSet<T>
Creates a new, empty bitset with a given domain_size.
Sourcepub fn new_filled(domain_size: usize) -> DenseBitSet<T>
pub fn new_filled(domain_size: usize) -> DenseBitSet<T>
Creates a new, filled bitset with a given domain_size.
Sourcepub fn superset(&self, other: &DenseBitSet<T>) -> bool
pub fn superset(&self, other: &DenseBitSet<T>) -> bool
Is self is a (non-strict) superset of other?
pub fn insert_range(&mut self, elems: impl RangeBounds<T>)
Sourcepub fn insert_all(&mut self)
pub fn insert_all(&mut self)
Sets all bits to true.
Sourcepub fn contains_any(&self, elems: impl RangeBounds<T>) -> bool
pub fn contains_any(&self, elems: impl RangeBounds<T>) -> bool
Checks whether any bit in the given range is a 1.
Sourcepub fn iter(&self) -> BitIter<'_, T> ⓘ
pub fn iter(&self) -> BitIter<'_, T> ⓘ
Iterates over the indices of set bits in a sorted order.
pub fn last_set_in(&self, range: impl RangeBounds<T>) -> Option<T>
Sourcepub fn union<Rhs>(&mut self, other: &Rhs) -> boolwhere
DenseBitSet<T>: BitRelations<Rhs>,
pub fn union<Rhs>(&mut self, other: &Rhs) -> boolwhere
DenseBitSet<T>: BitRelations<Rhs>,
Sets self = self | other and returns true if self changed
(i.e., if new bits were added).
Sourcepub fn subtract<Rhs>(&mut self, other: &Rhs) -> boolwhere
DenseBitSet<T>: BitRelations<Rhs>,
pub fn subtract<Rhs>(&mut self, other: &Rhs) -> boolwhere
DenseBitSet<T>: BitRelations<Rhs>,
Sets self = self - other and returns true if self changed.
(i.e., if any bits were removed).
Sourcepub fn intersect<Rhs>(&mut self, other: &Rhs) -> boolwhere
DenseBitSet<T>: BitRelations<Rhs>,
pub fn intersect<Rhs>(&mut self, other: &Rhs) -> boolwhere
DenseBitSet<T>: BitRelations<Rhs>,
Sets self = self & other and return true if self changed.
(i.e., if any bits were removed).
Sourcepub fn union_not(&mut self, other: &DenseBitSet<T>)
pub fn union_not(&mut self, other: &DenseBitSet<T>)
Sets self = self | !other.
FIXME: Incorporate this into BitRelations and fill out
implementations for other bitset types, if needed.