Binary

Trait Binary 

1.0.0 · Source
pub trait Binary {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
b formatting.

The Binary trait should format its output as a number in binary.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0b in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '101010' in binary

assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");

assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");

Implementing Binary on a type:

use std::fmt;

struct Length(i32);

impl fmt::Binary for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Binary::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(107);

assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");

assert_eq!(
    // Note that the `0b` prefix added by `#` is included in the total width, so we
    // need to add two to correctly display all 32 bits.
    format!("l as binary is: {l:#034b}"),
    "l as binary is: 0b00000000000000000000000001101011"
);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Binary for Access

Source

impl Binary for AtFlags

Source

impl Binary for BigInt

Source

impl Binary for BigUint

Source

impl Binary for rustix::backend::event::epoll::CreateFlags

Source

impl Binary for rustix::backend::fs::inotify::CreateFlags

Source

impl Binary for DupFlags

Source

impl Binary for EventFlags

Source

impl Binary for EventfdFlags

Source

impl Binary for FallocateFlags

Source

impl Binary for FdFlags

Source

impl Binary for FilterId

Source

impl Binary for FloatingPointEmulationControl

Source

impl Binary for FloatingPointExceptionMode

Source

impl Binary for Gid

Source

impl Binary for IFlags

Source

impl Binary for MemfdFlags

Source

impl Binary for Mode

Source

impl Binary for NonMaxI8

Source

impl Binary for NonMaxI16

Source

impl Binary for NonMaxI32

Source

impl Binary for NonMaxI64

Source

impl Binary for NonMaxI128

Source

impl Binary for NonMaxIsize

Source

impl Binary for NonMaxU8

Source

impl Binary for NonMaxU16

Source

impl Binary for NonMaxU32

Source

impl Binary for NonMaxU64

Source

impl Binary for NonMaxU128

Source

impl Binary for NonMaxUsize

Source

impl Binary for OFlags

Source

impl Binary for Pid

Source

impl Binary for PidfdFlags

Source

impl Binary for PidfdGetfdFlags

Source

impl Binary for PollFlags

Source

impl Binary for ReadFlags

Source

impl Binary for ReadWriteFlags

Source

impl Binary for RenameFlags

Source

impl Binary for ResolveFlags

Source

impl Binary for SealFlags

Source

impl Binary for SpeculationFeatureControl

Source

impl Binary for SpeculationFeatureState

Source

impl Binary for StatVfsMountFlags

Source

impl Binary for StatxAttributes

Source

impl Binary for StatxFlags

Source

impl Binary for TyFlags

Source

impl Binary for UInt<UTerm, B0>

Source

impl Binary for UInt<UTerm, B1>

Source

impl Binary for UTerm

Source

impl Binary for Uid

Source

impl Binary for UnalignedAccessControl

Source

impl Binary for WaitIdOptions

Source

impl Binary for WaitOptions

Source

impl Binary for WatchFlags

Source

impl Binary for WatchKind

Source

impl Binary for XattrFlags

Source

impl Binary for Z0

1.0.0 · Source

impl Binary for i8

1.0.0 · Source

impl Binary for i16

1.0.0 · Source

impl Binary for i32

1.0.0 · Source

impl Binary for i64

1.0.0 · Source

impl Binary for i128

1.0.0 · Source

impl Binary for isize

1.0.0 · Source

impl Binary for u8

1.0.0 · Source

impl Binary for u16

1.0.0 · Source

impl Binary for u32

1.0.0 · Source

impl Binary for u64

1.0.0 · Source

impl Binary for u128

1.0.0 · Source

impl Binary for usize

Source

impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,

Source

impl<'s, T> Binary for SliceVec<'s, T>
where T: Binary,

Source

impl<A> Binary for ArrayVec<A>
where A: Array, <A as Array>::Item: Binary,

Source

impl<A> Binary for TinyVec<A>
where A: Array, <A as Array>::Item: Binary,

1.0.0 · Source

impl<T> Binary for &T
where T: Binary + ?Sized,

1.0.0 · Source

impl<T> Binary for &mut T
where T: Binary + ?Sized,

1.28.0 · Source

impl<T> Binary for NonZero<T>

Source

impl<T> Binary for Ratio<T>
where T: Binary + Clone + Integer,

1.74.0 · Source

impl<T> Binary for Saturating<T>
where T: Binary,

1.11.0 · Source

impl<T> Binary for Wrapping<T>
where T: Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B0>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<U> Binary for NInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U> Binary for PInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<const BITS: usize, const LIMBS: usize> Binary for Signed<BITS, LIMBS>

Source

impl<const BITS: usize, const LIMBS: usize> Binary for Uint<BITS, LIMBS>