pub struct ItemId(/* private fields */);Expand description
A source unit item ID. Only used in SourceUnit.
Implementations
Sourceimpl ItemId
impl ItemId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub fn from_foreign<F>(value: F) -> ItemIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> ItemIdwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> ItemId
pub const unsafe fn from_usize_unchecked(value: usize) -> ItemId
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> ItemId
pub const unsafe fn from_raw_unchecked(raw: u32) -> ItemId
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> ItemId
pub const fn from_usize(value: usize) -> ItemId