pub struct GrowableBitSet<T>where
T: Idx,{ /* private fields */ }Expand description
A resizable bitset type with a dense representation.
T is an index type, typically a newtyped usize wrapper, but it can also
just be usize.
All operations that involve an element will panic if the element is equal to or greater than the domain size.
Implementations
Sourceimpl<T> GrowableBitSet<T>where
T: Idx,
impl<T> GrowableBitSet<T>where
T: Idx,
Sourcepub fn ensure(&mut self, min_domain_size: usize)
pub fn ensure(&mut self, min_domain_size: usize)
Ensure that the set can hold at least min_domain_size elements.
pub fn new_empty() -> GrowableBitSet<T>
pub fn with_capacity(capacity: usize) -> GrowableBitSet<T>
pub fn insert_range(&mut self, elems: Range<T>)
pub fn clear(&mut self)
pub fn count(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn contains(&self, elem: T) -> bool
pub fn contains_any(&self, elems: Range<T>) -> bool
pub fn iter(&self) -> BitIter<'_, T> ⓘ
pub fn len(&self) -> usize
Sourcepub fn union<Rhs>(&mut self, other: &Rhs) -> boolwhere
GrowableBitSet<T>: BitRelations<Rhs>,
pub fn union<Rhs>(&mut self, other: &Rhs) -> boolwhere
GrowableBitSet<T>: BitRelations<Rhs>,
Sets self = self | other and returns true if self changed
(i.e., if new bits were added).
Sourcepub fn subtract<Rhs>(&mut self, other: &Rhs) -> boolwhere
GrowableBitSet<T>: BitRelations<Rhs>,
pub fn subtract<Rhs>(&mut self, other: &Rhs) -> boolwhere
GrowableBitSet<T>: BitRelations<Rhs>,
Sets self = self - other and returns true if self changed.
(i.e., if any bits were removed).
Sourcepub fn intersect<Rhs>(&mut self, other: &Rhs) -> boolwhere
GrowableBitSet<T>: BitRelations<Rhs>,
pub fn intersect<Rhs>(&mut self, other: &Rhs) -> boolwhere
GrowableBitSet<T>: BitRelations<Rhs>,
Sets self = self & other and return true if self changed.
(i.e., if any bits were removed).