pub struct DeferredConst(/* private fields */);Expand description
A deferred constant identifier.
Deferred constants are immediates whose final value is only known after bytecode emission has observed lazy backend state, such as exact spill slot allocation. They must be resolved before assembly.
Implementations
Sourceimpl DeferredConst
impl DeferredConst
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub const fn new(value: usize) -> DeferredConst
pub const fn new(value: usize) -> DeferredConst
Sourcepub const fn from_raw(value: NonMaxU32) -> DeferredConst
pub const fn from_raw(value: NonMaxU32) -> DeferredConst
Create an index from a raw NonMaxU32 value.
Sourcepub fn from_foreign<F>(value: F) -> DeferredConstwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> DeferredConstwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> DeferredConst
pub const unsafe fn from_usize_unchecked(value: usize) -> DeferredConst
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> DeferredConst
pub const unsafe fn from_raw_unchecked(raw: u32) -> DeferredConst
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> DeferredConst
pub const fn from_usize(value: usize) -> DeferredConst
Sourceimpl DeferredConst
impl DeferredConst
Sourcepub const MAX: DeferredConst
pub const MAX: DeferredConst
The maximum index value.