pub struct IntScalar { /* private fields */ }Expand description
Represents an integer value for constant evaluation.
Implementations
Sourceimpl IntScalar
impl IntScalar
Sourcepub fn from_be_bytes(bytes: &[u8]) -> IntScalar
pub fn from_be_bytes(bytes: &[u8]) -> IntScalar
Creates a new integer value from big-endian bytes.
Panics
Panics if bytes is empty or has a length greater than 32.
Sourcepub fn bit_len(&self) -> u64
pub fn bit_len(&self) -> u64
Returns the bit length of the integer value.
This is the number of bits needed for the literal type.
Sourcepub fn is_negative(&self) -> bool
pub fn is_negative(&self) -> bool
Returns whether the value is negative.
Sourcepub fn as_u256(&self) -> Option<Uint<256, 4>>
pub fn as_u256(&self) -> Option<Uint<256, 4>>
Returns the non-negative integer value as unsigned data.
Sourcepub fn as_evm_word(&self) -> Uint<256, 4>
pub fn as_evm_word(&self) -> Uint<256, 4>
Returns the 256-bit two’s-complement EVM word for this integer value.